@@ -34,29 +34,18 @@ class Container(object):
   def __init__(self):
     self.contents = list()
 
-  def parse(self, reader):
-    "Parse by lines"
-    if hasattr(self, 'ending'):
-      self.parser.ending = self.ending
-    self.parser.factory = self.factory
-    self.header = self.parser.parseheader(reader)
-    self.begin = self.parser.begin
-    self.contents = self.parser.parse(reader)
-    self.parameters = self.parser.parameters
-    self.process()
-    self.parser = None
-
   def process(self):
     "Process contents"
     pass
 
-  def finished(self, reader):
-    "Find out if we are at the end"
-    return reader.currentline().startswith(self.ending)
-
   def gethtml(self):
     "Get the resulting HTML"
-    return self.output.gethtml(self)
+    html = self.output.gethtml(self)
+    if Options.html:
+      for index, piece in enumerate(html):
+        piece = piece.replace('/>', '>')
+        html[index] = piece
+    return html
 
   def __str__(self):
     "Get a description"
@@ -143,14 +132,14 @@ class StringContainer(Container):
     replaced = self.escape(line)
     replaced = self.changeline(replaced)
     self.contents = [replaced]
-    if '\\' in replaced and len(replaced) > 1:
+    if ContainerConfig.string['startcommand'] in replaced and len(replaced) > 1:
       # unprocessed commands
       Trace.error('Unknown command at ' + str(self.parser.begin) + ': '
           + replaced.strip())
 
   def changeline(self, line):
     line = self.replacemap(line, ContainerConfig.replaces)
-    if not '\\' in line:
+    if not ContainerConfig.string['startcommand'] in line:
       return line
     line = self.replacemap(line, ContainerConfig.commands)
     return line
@@ -183,7 +172,10 @@ class TaggedText(Container):
   "Text inside a tag"
 
   def __init__(self):
-    self.parser = TextParser()
+    ending = None
+    if self.__class__.__name__ in ContainerConfig.endings:
+      ending = ContainerConfig.endings[self.__class__.__name__]
+    self.parser = TextParser(ending)
     self.output = TaggedOutput()
 
   def complete(self, contents, tag, breaklines=False):
@@ -201,19 +193,3 @@ class TaggedText(Container):
   def __str__(self):
     return 'Tagged <' + self.tag + '>'
 
-class ContainerFactory(object):
-  "Creates containers depending on the first line"
-
-  def __init__(self, types):
-    self.tree = ParseTree(types)
-
-  def create(self, reader):
-    "Get the container and parse it"
-    #Trace.debug('processing "' + reader.currentline() + '"')
-    type = self.tree.find(reader)
-    container = type.__new__(type)
-    container.__init__()
-    container.factory = self
-    container.parse(reader)
-    return container
-
