@@ -34,8 +34,6 @@ from gen.layout import *
 class Float(Container):
   "A floating inset"
 
-  ending = '\\end_inset'
-
   def __init__(self):
     self.parser = InsetParser()
     self.output = TaggedOutput().settag('div class="float"', True)
@@ -64,8 +62,6 @@ class Wrap(Float):
 class InsetText(Container):
   "An inset of text in a lyx file"
 
-  ending = '\\end_inset'
-
   def __init__(self):
     self.parser = BoundedParser()
     self.output = ContentsOutput()
@@ -73,8 +69,6 @@ class InsetText(Container):
 class Caption(Container):
   "A caption for a figure or a table"
 
-  ending = '\\end_inset'
-
   def __init__(self):
     self.parser = InsetParser()
     self.output = TaggedOutput().settag('div class="caption"', True)
@@ -82,8 +76,6 @@ class Caption(Container):
 class Space(Container):
   "A space of several types"
 
-  ending = '\\end_inset'
-
   def __init__(self):
     self.parser = InsetParser()
     self.output = FixedOutput()
@@ -99,8 +91,6 @@ class Space(Container):
 class Inset(Container):
   "A generic inset in a LyX document"
 
-  ending = '\\end_inset'
-
   def __init__(self):
     self.contents = list()
     self.parser = InsetParser()
@@ -116,8 +106,6 @@ class Inset(Container):
 class NewlineInset(Newline):
   "A newline or line break in an inset"
 
-  ending = '\\end_inset'
-
   def __init__(self):
     self.parser = InsetParser()
     self.output = FixedOutput()
@@ -125,8 +113,6 @@ class NewlineInset(Newline):
 class Branch(Container):
   "A branch within a LyX document"
 
-  ending = '\\end_inset'
-
   def __init__(self):
     self.parser = InsetParser()
     self.output = TaggedOutput().settag('span class="branch"', True)
@@ -148,8 +134,6 @@ class Branch(Container):
 class ShortTitle(Container):
   "A short title to display (always hidden)"
 
-  ending = '\\end_inset'
-
   def __init__(self):
     self.parser = InsetParser()
     self.output = EmptyOutput()
@@ -157,8 +141,6 @@ class ShortTitle(Container):
 class Footnote(Container):
   "A footnote to the main text"
 
-  ending = '\\end_inset'
-
   order = 0
   list = 'ABCDEFGHIJKLMNOPQRSTUVWXYZ'
 
@@ -170,18 +152,20 @@ class Footnote(Container):
     "Add a letter for the order, rotating"
     letter = Footnote.list[Footnote.order % len(Footnote.list)]
     span = 'span class="FootMarker"'
-    fromfoot = TaggedText().constant(u'[→' + letter + u'] ', span)
+    pre = FootnoteConfig.constants['prefrom']
+    post = FootnoteConfig.constants['postfrom']
+    fromfoot = TaggedText().constant(pre + letter + post, span)
     self.contents.insert(0, fromfoot)
     tag = TaggedText().complete(self.contents, 'span class="Foot"', True)
-    tofoot = TaggedText().constant(' [' + letter + u'→] ', span)
+    pre = FootnoteConfig.constants['preto']
+    post = FootnoteConfig.constants['postto']
+    tofoot = TaggedText().constant(pre + letter + post, span)
     self.contents = [tofoot, tag]
     Footnote.order += 1
 
 class Note(Container):
   "A LyX note of several types"
 
-  ending = '\\end_inset'
-
   typetags = {'Note':'', 'Comment':'', 'Greyedout':'span class="greyedout"'}
 
   def __init__(self):
@@ -195,32 +179,9 @@ class Note(Container):
       return
     self.output = TaggedOutput().settag(Note.typetags[self.type], True)
 
-class DeeperList(Container):
-  "A nested list"
-
-  ending = '\\end_deeper'
-
-  def __init__(self):
-    self.parser = BoundedParser()
-    self.output = ContentsOutput()
-
-  def process(self):
-    "Create the deeper list"
-    if len(self.contents) == 0:
-      Trace.error('Empty deeper list')
-      return
-
-  def __str__(self):
-    result = 'deeper list @ ' + str(self.begin) + ': ['
-    for element in self.contents:
-      result += str(element) + ', '
-    return result[:-2] + ']'
-
 class FlexCode(Container):
   "A bit of inset code"
 
-  ending = '\\end_inset'
-
   def __init__(self):
     self.parser = InsetParser()
     self.output = TaggedOutput().settag('span class="code"', True)
@@ -228,8 +189,6 @@ class FlexCode(Container):
 class InfoInset(Container):
   "A LyX Info inset"
 
-  ending = '\\end_inset'
-
   types = ['shortcut', 'shortcuts', 'package', 'textclass']
 
   def __init__(self):
@@ -246,8 +205,6 @@ class InfoInset(Container):
 class ERT(Container):
   "Evil Red Text"
 
-  ending = '\\end_inset'
-
   def __init__(self):
     self.parser = InsetParser()
     self.output = EmptyOutput()
@@ -255,8 +212,6 @@ class ERT(Container):
 class Listing(Container):
   "A code listing"
 
-  ending = '\\end_inset'
-
   def __init__(self):
     self.parser = InsetParser()
     self.output = TaggedOutput().settag('code class="listing"', True)
@@ -307,13 +262,11 @@ class Listing(Container):
 class BoxInset(Container):
   "A box inset"
 
-  ending = '\\end_inset'
-
-  typetags = {'Framed':'div class="framed"'}
+  typetags = {'Framed':'div class="framed"', 'Frameless':'div class="frameless"'}
 
   def __init__(self):
     self.parser = InsetParser()
-    self.output = TaggedOutput()
+    self.output = TaggedOutput().settag('div', True)
 
   def process(self):
     "Set the correct tag"
