@@ -32,23 +32,20 @@ from gen.container import *
 class LyxHeader(Container):
   "Reads the header, outputs the HTML header"
 
-  ending = '\\end_header'
-
   def __init__(self):
     self.parser = HeaderParser()
     self.output = HeaderOutput()
 
   def process(self):
     "Find pdf title"
-    if '\\pdf_title' in self.parser.parameters:
-      Options.title = self.parser.parameters['\\pdf_title']
+    key = ContainerConfig.header['pdftitle']
+    if key in self.parameters:
+      Options.title = self.parameters[key]
       Trace.debug('PDF Title: ' + Options.title)
 
 class LyxFooter(Container):
   "Reads the footer, outputs the HTML footer"
 
-  ending = '\\end_document'
-
   def __init__(self):
     self.parser = BoundedDummy()
     self.output = FooterOutput()
@@ -56,8 +53,6 @@ class LyxFooter(Container):
 class Align(Container):
   "Bit of aligned text"
 
-  ending = '\\end_layout'
-
   def __init__(self):
     self.parser = ExcludingParser()
     self.output = TaggedOutput().setbreaklines(True)
@@ -86,8 +81,6 @@ class Appendix(Container):
 class ListItem(Container):
   "An element in a list"
 
-  ending = '\\end_layout'
-
   def __init__(self):
     "Output should be empty until the postprocessor can group items"
     self.contents = list()
@@ -108,8 +101,6 @@ class ListItem(Container):
 class DeeperList(Container):
   "A nested list"
 
-  ending = '\\end_deeper'
-
   def __init__(self):
     self.parser = BoundedParser()
     self.output = ContentsOutput()
