@@ -32,8 +32,6 @@ from parse.tableparse import *
 class Table(Container):
   "A lyx table"
 
-  ending = '\\end_inset'
-
   def __init__(self):
     self.parser = TableParser()
     self.output = TaggedOutput().settag('table', True)
@@ -41,8 +39,6 @@ class Table(Container):
 class Row(Container):
   "A row in a table"
 
-  ending = '</row'
-
   def __init__(self):
     self.parser = TablePartParser()
     self.output = TaggedOutput().settag('tr', True)
@@ -64,8 +60,6 @@ class Row(Container):
 class Cell(Container):
   "A cell in a table"
 
-  ending = '</cell'
-
   def __init__(self):
     self.parser = TablePartParser()
     self.output = TaggedOutput().settag('td', True)
