@@ -135,11 +135,19 @@ class LoneCommand(Parser):
 class TextParser(Parser):
   "A parser for a command and a bit of text"
 
-  endings = ['\\end_layout', '\\end_inset', '\\emph', '\\family', '\\noun',
-      '\\color', '\\size', '\\series']
+  stack = []
+
+  def __init__(self, ending):
+    Parser.__init__(self)
+    self.ending = ending
+    self.endings = []
 
   def parse(self, reader):
     "Parse lines as long as they are text"
+    TextParser.stack.append(self.ending)
+    self.endings = TextParser.stack + [ContainerConfig.endings['Layout'],
+        ContainerConfig.endings['Inset'], self.ending]
+    Trace.debug('Stack: ' + str(TextParser.stack))
     contents = []
     while not self.isending(reader):
       container = self.factory.create(reader)
@@ -150,8 +158,15 @@ class TextParser(Parser):
     "Check if text is ending"
     current = reader.currentsplit()
     if len(current) == 0:
+      return False
+    if current[0] in self.endings:
+      Trace.debug('Ending ' + current[0])
+      if current[0] in TextParser.stack:
+        TextParser.stack.remove(current[0])
+      else:
+        TextParser.stack = []
       return True
-    return current[0] in TextParser.endings
+    return False
 
 class ExcludingParser(Parser):
   "A parser that excludes the final line"
@@ -204,7 +219,8 @@ class InsetParser(BoundedParser):
 
   def parse(self, reader):
     "Parse inset parameters into a dictionary"
-    while reader.currentline() != '\n' and not reader.currentline().startswith('\\'):
+    startcommand = ContainerConfig.string['startcommand']
+    while reader.currentline() != '\n' and not reader.currentline().startswith(startcommand):
       self.parseparameter(reader)
     return BoundedParser.parse(self, reader)
 
@@ -223,17 +239,16 @@ class HeaderParser(Parser):
   def parseline(self, reader):
     "Parse a single line as a parameter or as a start"
     line = reader.currentline()
-    for key in HeaderParser.openings:
-      if line.startswith(key):
-        HeaderParser.openings[key](self, reader)
-        return
+    if line.startswith(ContainerConfig.header['branch']):
+      self.parsebranch(reader)
+      return
     # no match
     self.parseparameter(reader)
 
   def parsebranch(self, reader):
     branch = reader.currentline().split()[1]
     reader.nextline()
-    subparser = HeaderParser().complete('\\end_branch')
+    subparser = HeaderParser().complete(ContainerConfig.header['endbranch'])
     subparser.parse(reader)
     options = BranchOptions()
     for key in subparser.parameters:
@@ -244,5 +259,3 @@ class HeaderParser(Parser):
     self.ending = ending
     return self
 
-  openings = {'\\branch':parsebranch}
-
