@@ -50,10 +50,6 @@ class Link(Container):
 class ListOf(Container):
   "A list of entities (figures, tables, algorithms)"
 
-  ending = '\\end_inset'
-
-  names = {'figure':'figures', 'table':'tables', 'algorithm':'listings'}
-
   def __init__(self):
     self.parser = BoundedParser()
     self.output = TaggedOutput().settag('div class="list"', True)
@@ -61,26 +57,22 @@ class ListOf(Container):
   def process(self):
     "Parse the header and get the type"
     self.type = self.header[2]
-    self.contents = [Constant(u'List of ' + ListOf.names[self.type])]
+    self.contents = [Constant(TranslationConfig.lists[self.type])]
 
 class TableOfContents(Container):
   "Table of contents"
 
-  ending = '\\end_inset'
-
   def __init__(self):
     self.parser = BoundedParser()
     self.output = TaggedOutput().settag('div class="toc"', True)
 
   def process(self):
     "Parse the header and get the type"
-    self.contents = [Constant(u'Table of Contents')]
+    self.contents = [Constant(TranslationConfig.constants['toc'])]
 
 class IndexEntry(Link):
   "An entry in the alphabetical index"
 
-  ending = '\\end_inset'
-
   entries = dict()
 
   namescapes = {'!':'', '|':', ', '  ':' '}
@@ -107,8 +99,6 @@ class IndexEntry(Link):
 class LayoutIndexEntry(IndexEntry):
   "An entry with the name in a layout"
 
-  ending = '\\end_inset'
-
   def process(self):
     "Read entry from layout and put in index"
     name = ''
@@ -124,15 +114,14 @@ class LayoutIndexEntry(IndexEntry):
 class PrintIndex(Container):
   "Command to print an index"
 
-  ending = '\\end_inset'
-
   def __init__(self):
     self.parser = BoundedParser()
     self.output = ContentsOutput()
 
   def process(self):
     "Create the alphabetic index"
-    self.contents = [TaggedText().constant('Index', 'h1 class="index"'),
+    index = TranslationConfig.constants['index']
+    self.contents = [TaggedText().constant(index, 'h1 class="index"'),
         Constant('\n')]
     for key in self.sortentries():
       name = IndexEntry.entries[key][0].name
@@ -162,8 +151,6 @@ class PrintIndex(Container):
 class NomenclatureEntry(Link):
   "An entry of LyX nomenclature"
 
-  ending = '\\end_inset'
-
   entries = {}
 
   def __init__(self):
@@ -183,15 +170,14 @@ class NomenclatureEntry(Link):
 class NomenclaturePrint(Container):
   "Print all nomenclature entries"
 
-  ending = '\\end_inset'
-
   def __init__(self):
     self.parser = InsetParser()
     self.output = ContentsOutput()
 
   def process(self):
     self.keys = self.sortentries()
-    self.contents = [TaggedText().constant('Nomenclature', 'h1 class="nomenclature"')]
+    nomenclature = TranslationConfig.constants['nomenclature']
+    self.contents = [TaggedText().constant(nomenclature, 'h1 class="nomenclature"')]
     for key in self.keys:
       entry = NomenclatureEntry.entries[key]
       contents = [Link().complete(u'↑', 'nom-' + key, '#noment-' + key)]
@@ -210,8 +196,6 @@ class NomenclaturePrint(Container):
 class URL(Link):
   "A clickable URL"
 
-  ending = '\\end_inset'
-
   def __init__(self):
     self.parser = InsetParser()
     self.output = LinkOutput()
@@ -229,8 +213,6 @@ class URL(Link):
 class FlexURL(URL):
   "A flexible URL"
 
-  ending = '\\end_inset'
-
   def process(self):
     "Read URL from contents"
     text = self.searchfor(StringContainer).contents[0]
