@@ -38,6 +38,7 @@ class Options(object):
   version = False
   hardversion = False
   versiondate = False
+  html = False
   help = False
   showlines = True
   css = 'http://www.nongnu.org/elyxer/lyx.css'
@@ -75,6 +76,7 @@ class Options(object):
     Trace.error('    --title <title>: set the generated page title')
     Trace.error('    --css <file.css>: use a custom CSS file')
     Trace.error('    --version: show version number and release date')
+    Trace.error('    --html: output HTML 4.0 instead of the default XHTML')
     exit()
 
   def showversion(self):
@@ -103,9 +105,9 @@ class BranchOptions(object):
 
   def set(self, key, value):
     "Set a branch option"
-    if not key.startswith('\\'):
+    if not key.startswith(ContainerConfig.string['startcommand']):
       Trace.error('Invalid branch option ' + key)
       return
-    key = key.replace('\\', '')
+    key = key.replace(ContainerConfig.string['startcommand'], '')
     setattr(self, key, value)
 
